<?php
/* $Id: german-utf-8.inc.php,v 2.99 2005/08/20 20:10:39 lem9 Exp $ */

/**
 * For suggestions concerning this file please contact
 *     Alexander M. Turek <rabus at users.sourceforge.net>.
 *
 * Bei Verbesserungsvorschlägen diese Datei betreffend wenden Sie sich bitte an
 *     Alexander M. Turek <rabus at users.sourceforge.net>.
 */

$charset = 'utf-8';
$allow_recoding = TRUE;
$text_dir = 'ltr';
$left_font_family = 'verdana, arial, helvetica, geneva, sans-serif';
$right_font_family = 'arial, helvetica, geneva, sans-serif';
$number_thousands_separator = '.';
$number_decimal_separator = ',';
// shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
$byteUnits = array('Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');

$day_of_week = array('So', 'Mo', 'Di', 'Mi', 'Do', 'Fr', 'Sa');
$month = array('Januar', 'Februar', 'März', 'April', 'Mai', 'Juni', 'Juli', 'August', 'September', 'Oktober', 'November', 'Dezember');
// See http://www.php.net/manual/en/function.strftime.php to define the
// variable below
$datefmt = '%d. %B %Y um %H:%M';
$timespanfmt = '%s Tage, %s Stunden, %s Minuten und %s Sekunden';

$strAbortedClients = 'Abgebrochen';
$strAbsolutePathToDocSqlDir = 'Bitte geben Sie den vollständigen Pfad auf dem Webserver zum docSQL-Verzeichnis ein.';
$strAccessDeniedExplanation = 'phpMyAdmin hat versucht eine Verbindung zum MySQL-Server aufzubauen, jedoch hat dieser die Verbindung zurückgewiesen. Sie sollten Ihre Einstellungen für Host, Benutzername und Kennwort in Ihrer config.inc.php überprüfen und sich vergewissern, dass diese den Informationen, welche sie vom Administrator erhalten haben, entsprechen.';
$strAccessDenied = 'Zugriff verweigert.';
$strAction = 'Aktion';
$strAddAutoIncrement = 'AUTO_INCREMENT-Wert hinzufügen';
$strAddConstraints = 'Constraints hinzufügen';
$strAddDeleteColumn = 'Spalten hinzufügen/entfernen';
$strAddDeleteRow = 'Zeilen hinzufügen/entfernen';
$strAddDropDatabase = 'DROP DATABASE hinzufügen';
$strAddedColumnComment = 'Spaltenkommentar wurde hinzugefügt';
$strAddedColumnRelation = 'Spaltenbeziehung wurde hinzugefügt';
$strAddFields = '%s Felder hinzufügen';
$strAddHeaderComment = 'Individuelle Kommentare für den Kopfbereich (\\n erzeugt einen Zeilenumbruch)';
$strAddIfNotExists = 'Mit \'IF NOT EXISTS\'';
$strAddIntoComments = 'In Kommentarbereich einbeziehen';
$strAddNewField = 'Neue Felder hinzufügen';
$strAddPrivilegesOnDb = 'Rechte zu folgender Datenbank hinzufügen';
$strAddPrivilegesOnTbl = 'Rechte zu folgender Tabelle hinzufügen';
$strAddSearchConditions = 'Eigenes Filterkriterium (Argumente für den WHERE-Ausdruck):';
$strAddToIndex = '%s&nbsp;Spalten zum Index hinzufügen';
$strAddUserMessage = 'Der Benutzer wurde hinzugefügt.';
$strAddUser = 'Neuen Benutzer hinzufügen';
$strAdministration = 'Administration';
$strAffectedRows = ' Betroffene Datensätze: ';
$strAfterInsertBack = 'zurück';
$strAfterInsertNewInsert = 'anschließend einen weiteren Datensatz einfügen';
$strAfterInsertNext = 'nächste Zeile bearbeiten';
$strAfterInsertSame = 'Zurück zu dieser Seite';
$strAfter = 'Nach %s';
$strAll = 'Alle';
$strAllTableSameWidth = 'Sollen alle Tabellen mit der gleichen Breite angezeigt werden?';
$strAlterOrderBy = 'Tabelle sortieren nach';
$strAnalyzeTable = 'Analysiere Tabelle';
$strAnd = 'und';
$strAnIndex = 'Ein Index wurde in %s erzeugt';
$strAnyHost = 'Jeder Host';
$strAny = 'Jeder';
$strAnyUser = 'Jeder Benutzer';
$strApproximateCount = 'Es kann sich hierbei um Näherungswerte handeln. Bitte lesen Sie auch FAQ 3.11';
$strAPrimaryKey = 'Ein Primärschlüssel wurde in %s erzeugt';
$strArabic = 'Arabisch';
$strArmenian = 'Armenisch';
$strAscending = 'aufsteigend';
$strAtBeginningOfTable = 'An den Anfang der Tabelle';
$strAtEndOfTable = 'An das Ende der Tabelle';
$strAttr = 'Attribute';
$strAutodetect = 'Autom. Erkennung';
$strAutomaticLayout = 'Automatische Anordnung';

$strBack = 'Zurück';
$strBaltic = 'Baltisch';
$strBeginCut = 'AUSSCHNITTSANFANG';
$strBeginRaw = 'BEGINN DER AUSGABE';
$strBinary = 'Binär';
$strBinaryDoNotEdit = 'Binär - nicht editierbar!';
$strBinaryLog = 'Binäres Protokoll';
$strBinLogEventType = 'Ereignistyp';
$strBinLogInfo = 'Information';
$strBinLogName = 'Protokoll';
$strBinLogOriginalPosition = 'Ursprungsposition';
$strBinLogPosition = 'Position';
$strBinLogServerId = 'Server-ID';
$strBookmarkAllUsers = 'Diese gespeicherte SQL-Abfrage für jeden Benutzer verfügbar machen';
$strBookmarkDeleted = 'SQL-Abfrage wurde gelöscht.';
$strBookmarkLabel = 'Titel';
$strBookmarkOptions = 'Optionen zur Speicherung der SQL-Abfrage';
$strBookmarkQuery = 'Gespeicherte SQL-Abfrage';
$strBookmarkThis = 'SQL-Abfrage speichern';
$strBookmarkView = 'Nur zeigen';
$strBrowse = 'Anzeigen';
$strBrowseForeignValues = 'Fremdschlüsselwerte ansehen';
$strBufferPoolActivity = 'Speicherpuffer-Aktivität';
$strBufferPool = 'Speicherpuffer';
$strBufferPoolUsage = 'Auslastung des Speicherpuffers';
$strBufferReadMisses = 'Fehlgeschlagene Leseanfragen';
$strBufferReadMissesInPercent = 'Fehlgeschlagene Leseanfragen in %';
$strBufferWriteWaitsInPercent = 'Schreibverzögerungen in %';
$strBufferWriteWaits = 'Schreibverzögerungen';
$strBulgarian = 'Bulgarisch';
$strBusyPages = 'Ausgelastete Seiten';
$strBzError = 'phpMyAdmin konnte die Datei wegen eines Fehler in der Bz2-Erweiterung in dieser php-Version nicht komprimieren. Es wird deshalb empfohlen die Einstellung <code>$cfg[\'BZipDump\']</code> in Ihrer phpMyAdmin-Konfiguration auf <code>FALSE</code> zu setzen. Falls Sie die Bz2-Kompressionsfunktionen dennoch nutzen wollen, so sollten Sie eine neuere php-Version installieren. Bitte lesen Sie auch den php-Bugreport %s für weitere Informationen.';
$strBzip = 'BZip-komprimiert';

$strCalendar = 'Kalender';
$strCannotLogin = 'Die Anmeldung am MySQL-Server ist fehlgeschlagen.';
$strCantLoad = 'Die Erweiterung &quot;%s&quot; kann nicht geladen werden.<br />Bitte überprüfen Sie Ihre PHP-Konfiguration.';
$strCantLoadRecodeIconv = 'Die PHP-Erweiterungen iconv und recode, welche für die Zeichensatzkonvertierung benötigt werden, konnten nicht geladen werden. Bitte ändern Sie Ihre PHP-Konfiguration und aktivieren Sie diese Erweiterungen oder deaktivieren Sie die Zeichensatzkonvertierung in phpMyAdmin.';
$strCantRenameIdxToPrimary = 'Kann Index nicht in PRIMARY umbenennen!';
$strCantUseRecodeIconv = 'Weder die iconv- noch libiconv- oder recode_string-Funktion konnte verwandt werden, obwohl die benötigten php-Erweiterungen angeblich geladen wurden. Bitte überprüfen Sie Ihre PHP-Konfiguration.';
$strCardinality = 'Kardinalität';
$strCarriage = 'Wagenrücklauf \\r';
$strCaseInsensitive = 'case-insensitive';
$strCaseSensitive = 'case-sensitive';
$strCentralEuropean = 'Mitteleuropäisch';
$strChange = 'Ändern';
$strChangeCopyModeCopy = ' ... behalte den alten bei.';
$strChangeCopyModeDeleteAndReload = ' ... lösche den alten und lade anschließend die Benutzertabellen neu.';
$strChangeCopyMode = 'Erstelle einen neuen Benutzer mit identischen Rechten und ...';
$strChangeCopyModeJustDelete = ' ... lösche den alten von den Benutzertabellen.';
$strChangeCopyModeRevoke = ' ... entziehe dem alten alle Rechte und lösche ihn anschließend.';
$strChangeCopyUser = 'Logininformation ändern / Benutzer kopieren';
$strChangeDisplay = 'Anzuzeigende Spalte bestimmen';
$strChangePassword = 'Kennwort ändern';
$strCharsetOfFile = 'Zeichencodierung der Datei:';
$strCharsetsAndCollations = 'Zeichensätze und Kollationen';
$strCharsets = 'Zeichensätze';
$strCharset = 'Zeichensatz';
$strCheckAll = 'Alle auswählen';
$strCheckOverhead = 'Tabellen m. Überhang ausw.';
$strCheckPrivsLong = 'Überprüft die Rechte für die Datenbank &quot;%s&quot;.';
$strCheckPrivs = 'Rechte überprüfen';
$strCheckTable = 'Überprüfe Tabelle';
$strChoosePage = 'Bitte wählen Sie die zu bearbeitende Seite.';
$strColComFeat = 'Darstellung von Spaltenkommentaren';
$strCollation = 'Kollation';
$strColumnNames = 'Spaltennamen';
$strColumnPrivileges = 'Spaltenspezifische Rechte';
$strCommand = 'Befehl';
$strCommentsForTable = 'TABELLENKOMMENTARE';
$strComments = 'Kommentare';
$strCompatibleHashing = 'MySQL&nbsp;4.0 kompatibel';
$strCompleteInserts = 'Vollständige \'INSERT\'s';
$strCompression = 'Kompression';
$strConfigFileError = 'phpMyAdmin konnte Ihre Konfigurationsdatei nicht verarbeiten!<br />Dies kann passieren, wenn der PHP-Parser Syntaxfehler in ihr findet oder sie nicht existiert.<br />Bitte rufen Sie die Konfigurationsdatei über den unteren Link direkt auf und lesen Sie die PHP-Fehlermeldungen, die Sie erhalten. Meistens fehlt bloß irgendwo ein Anführungszeichen oder Semikolon.<br />Wenn Sie eine leere Seite erhalten, ist Ihre Konfigurationsdatei in Ordnung.';
$strConfigureTableCoord = 'Bitte konfigurieren Sie die Koordinaten für die Tabelle %s';
$strConnectionError = 'Die Verbindung konnte aufgrund von ungültigen Einstellungen nicht hergestellt werden.';
$strConnections = 'Verbindungen';
$strConstraintsForDumped = 'Constraints der exportierten Tabellen';
$strConstraintsForTable = 'Constraints der Tabelle';
$strCookiesRequired = 'Ab diesem Punkt müssen Cookies aktiviert sein.';
$strCopyDatabaseOK = 'Datenbank %s wurde nach %s kopiert';
$strCopy = 'Kopieren';
$strCopyTable = 'Kopiere Tabelle nach (Datenbank<b>.</b>Tabellenname):';
$strCopyTableOK = 'Tabelle %s wurde nach %s kopiert.';
$strCopyTableSameNames = 'Tabelle kann nicht mit gleichem Namen kopiert werden!';
$strCouldNotKill = 'phpMyAdmin konnte den Prozess %s nicht abbrechen. Er wurde wahrscheinlich bereits geschlossen.';
$strCreate = 'Anlegen';
$strCreateDatabaseBeforeCopying = 'Vor dem Kopieren CREATE DATABASE ausführen.';
$strCreateIndex = 'Index über&nbsp;%s&nbsp;Spalten anlegen';
$strCreateIndexTopic = 'Neuen Index anlegen';
$strCreateNewDatabase = 'Neue Datenbank anlegen';
$strCreateNewTable = 'Neue Tabelle in Datenbank %s erstellen';
$strCreatePage = 'Neue Seite erstellen';
$strCreatePdfFeat = 'Erzeugen von PDFs';
$strCreationDates = 'Erzeugungs- / Aktualisierungs- / Überprüfungszeiten';
$strCriteria = 'Kriterium';
$strCroatian = 'Kroatisch';
$strCSVOptions = 'CSV-Optionen';
$strCyrillic = 'Kyrillisch';
$strCzechSlovak = 'Tschechoslowakisch';
$strCzech = 'Tschechisch';

$strDanish = 'Dänisch';
$strDatabase = 'Datenbank';
$strDatabaseEmpty = 'Der Datenbankname ist leer!';
$strDatabaseExportOptions = 'Export-Optionen der Datenbank';
$strDatabaseHasBeenDropped = 'Datenbank %s wurde gelöscht.';
$strDatabaseNoTable = 'Diese Datenbank enthält keine Tabelle!';
$strDatabases = 'Datenbanken';
$strDatabasesDropped = 'Es wurden %s Datenbanken gelöscht.';
$strDatabasesStatsDisable = 'Datenbankstatistiken deaktivieren';
$strDatabasesStatsEnable = 'Datenbankstatistiken aktivieren';
$strDatabasesStatsHeavyTraffic = 'Bitte beachten Sie: Das Aktivieren der Datenbankstatistiken kann starken Traffic zwischen dem Web- und dem MySQL-Server zur Folge haben.';
$strDatabasesStats = 'Statistik über alle Datenbanken';
$strData = 'Daten';
$strDataDict = 'Strukturverzeichnis';
$strDataOnly = 'Nur Daten';
$strDataPages = 'Daten enthaltende Seiten';
$strDBComment = 'Datenbankkommentar: ';
$strDBCopy = 'Datenbank kopieren nach';
$strDBGContextID = 'Kontext-ID';
$strDBGContext = 'Kontext';
$strDBGHits = 'Treffer';
$strDBGLine = 'Zeile';
$strDBGMaxTimeMs = 'Max. Zeit in ms';
$strDBGMinTimeMs = 'Min. Zeit in ms';
$strDBGModule = 'Modul';
$strDBGTimePerHitMs = 'Zeit/Treffer in ms';
$strDBGTotalTimeMs = 'Gesamtzeit in ms';
$strDbPrivileges = 'Datenbankspezifische Rechte';
$strDBRename = 'Datenbank umbenennen in';
$strDbSpecific = 'datenbankspezifisch';
$strDefaultEngine = 'Neue Tabellen werden standardmäßig im Format %s angelegt.';
$strDefault = 'Standard';
$strDefaultValueHelp = 'Bitte geben Sie jeweils nur einen Standardwert ohne Escape- oder Anführungszeichen an.';
$strDefragment = 'Tabelle defragmentieren';
$strDelayedInserts = 'Verzögerten INSERT-Befehl verwenden';
$strDeleteAndFlushDescr = 'Dies ist zwar der sauberste Weg, jedoch kann es einige Zeit in Anspruch nehmen, die Benutzertabellen neu zu laden.';
$strDeleteAndFlush = 'Die Benutzer löschen und die Benutzertabellen anschließend neu laden.';
$strDeleted = 'Die Zeile wurde gelöscht.';
$strDeletedRows = 'Gelöschte Zeilen:';
$strDelete = 'Löschen';
$strDeleting = 'Lösche %s';
$strDelOld = 'Auf der aktuellen Seite bestehen Referenzen zu Tabellen, die nicht mehr existieren. Sollen diese Referenzen gelöscht werden?';
$strDescending = 'absteigend';
$strDescription = 'Beschreibung';
$strDictionary = 'Wörterbuch';
$strDirtyPages = 'Inkonsistente Seiten (&quot;dirty&quot;)';
$strDisabled = 'Deaktiviert';
$strDisableForeignChecks = 'Fremdschlüsselüberprüfung deaktivieren';
$strDisplayFeat = 'Anzeige verknüpfter Daten';
$strDisplayOrder = 'Sortierung nach:';
$strDisplayPDF = 'PDF-Schema anzeigen';
$strDoAQuery = 'Suche über Beispielwerte ("query by example") (Platzhalter: "%")';
$strDocu = 'Dokumentation';
$strDoYouReally = 'Möchten Sie wirklich diese Abfrage ausführen ';
$strDropDatabaseStrongWarning = 'Sie sind dabei eine komplette Datenbank zu ZERSTÖREN!';
$strDrop = 'Löschen';
$strDropSelectedDatabases = 'Ausgewählte Datenbanken löschen';
$strDropUsersDb = 'Die gleichnamigen Datenbanken löschen.';
$strDumpingData = 'Daten für Tabelle';
$strDumpSaved = 'Dump (Schema) wurde in Datei %s gespeichert.';
$strDumpXRows = 'Exportiere %s Datensätze ab Zeile %s.';
$strDynamic = 'dynamisch';

$strEdit = 'Bearbeiten';
$strEditPDFPages = 'PDF-Seiten bearbeiten';
$strEditPrivileges = 'Rechte ändern';
$strEffective = 'Effektiv';
$strEmpty = 'Leeren';
$strEmptyResultSet = 'MySQL lieferte ein leeres Resultat zurück (d.h. null Zeilen).';
$strEnabled = 'Aktiviert';
$strEncloseInTransaction = 'Export in einer Transaktion zusammenfassen';
$strEndCut = 'AUSSCHNITTSENDE';
$strEnd = 'Ende';
$strEndRaw = 'ENDE DER AUSGABE';
$strEngineAvailable = '%s ist auf diesem MySQL-Server verfügbar.';
$strEngineDisabled = '%s wurde auf diesem MySQL-Server deaktiviert.';
$strEngines = 'Formate';
$strEngineUnsupported = 'Dieser MySQL-Server unterstützt %s nicht.';
$strEnglish = 'Englisch';
$strEnglishPrivileges = ' Anmerkung: MySQL-Rechte werden auf Englisch angegeben. ';
$strError = 'Fehler';
$strEscapeWildcards = 'Platzhalter _ und % sollten mit einem \ escaped werden, um das gewünschte Sonderzeichen einzubinden';
$strEstonian = 'Estnisch';
$strExcelEdition = 'Excel-Ausgabe';
$strExcelOptions = 'Excel-Optionen';
$strExecuteBookmarked = 'Gespeicherte SQL-Anfrage ausführen';
$strExplain = 'SQL erklären';
$strExport = 'Exportieren';
$strExtendedInserts = 'Erweiterte \'INSERT\'s';
$strExtra = 'Extra';

$strFailedAttempts = 'Fehlgeschlagen';
$strField = 'Feld';
$strFieldHasBeenDropped = 'Spalte %s wurde entfernt.';
$strFieldsEmpty = ' Sie müssen angeben wie viele Felder die Tabelle haben soll! ';
$strFieldsEnclosedBy = 'Felder eingeschlossen von';
$strFieldsEscapedBy = 'Felder escaped von';
$strFields = 'Felder';
$strFieldsTerminatedBy = 'Felder getrennt mit';
$strFileAlreadyExists = 'Die Datei %s besteht bereits auf dem Server. Bitte ändern Sie den Dateinamen oder wählen Sie die Überschreibungs-Option.';
$strFileCouldNotBeRead = 'Die Datei konnte nicht gelesen werden';
$strFileNameTemplate = 'Dateinamenskonvention';
$strFileNameTemplateHelp = 'Benutzen Sie __DB__ für den Datenbanknamen, __TABLE__ für den Tabellennamen und %sbeliebige strftime-Optionen%s zur Angabe von Datumsvariablen. Die Erweiterung wird automatisch hinzugefügt. Jeglicher anderer Text wird beibehalten.';
$strFileNameTemplateRemember = 'Konvention merken';
$strFixed = 'starr';
$strFlushPrivilegesNote = 'Anmerkung: phpMyAdmin liest die Benutzerprofile direkt aus den entsprechenden MySQL-Tabellen aus. Der Inhalt dieser Tabellen kann sich von den Benutzprofilen, die MySQL z.Zt. verwendet, unterscheiden, wenn manuelle Änderungen vorgenommen wurden. In diesem Fall sollten Sie  %sdie Benutzerprofile neu laden%s bevor Sie fortfahren.';
$strFlushTable = 'Leeren des Tabellenchaches ("FLUSH")';
$strFormat = 'Format';
$strFormEmpty = 'Das Formular ist leer !';
$strFreePages = 'Unbenutzte Seiten';
$strFullText = 'vollständige Textfelder';
$strFunction = 'Funktion';

$strGenBy = 'Erstellt von';
$strGeneralRelationFeat = 'Allgemeine Verknüpfungsfunktionen';
$strGenerate = 'Generieren';
$strGeneratePassword = 'Passwort generieren';
$strGenTime = 'Erstellungszeit';
$strGeorgian = 'Georgisch';
$strGerman = 'Deutsch';
$strGlobal = 'global';
$strGlobalPrivileges = 'Globale Rechte';
$strGlobalValue = 'Globaler Wert';
$strGo = 'OK';
$strGrantOption = 'Grant';
$strGreek = 'Griechisch';
$strGzip = 'GZip-komprimiert';

$strHasBeenAltered = 'wurde geändert.';
$strHasBeenCreated = 'wurde erzeugt.';
$strHaveToShow = 'Bitte wählen Sie mindestens eine anzuzeigende Spalte';
$strHebrew = 'Hebräisch';
$strHexForBinary = 'Hexadezimalschreibweise für Binärfelder verwenden';
$strHome = 'Home';
$strHomepageOfficial = ' Offizielle phpMyAdmin-Homepage ';
$strHostEmpty = 'Es wurde kein Host angegeben!';
$strHost = 'Host';
$strHTMLExcel = 'Microsoft Excel 2000';
$strHTMLExcelOptions = 'Exportoptionen für Microsoft Excel 2000';
$strHTMLWord = 'Microsoft Word 2000';
$strHTMLWordOptions = 'Exportoptionen für Microsoft Word 2000';
$strHungarian = 'Ungarisch';

$strIcelandic = 'Isländisch';
$strId = 'ID';
$strIdxFulltext = 'Volltext';
$strIfYouWish = 'Wenn Sie nur bestimmte Spalten importieren möchten, geben Sie diese bitte hier an.';
$strIgnore = 'Ignorieren';
$strIgnoreInserts = 'Fehlerübergehenden INSERT-Befehl verwenden';
$strIgnoringFile = 'Die Datei %s wird ignoriert';
$strImportDocSQL = 'docSQL-Dateien importieren';
$strImportFiles = 'Dateiimport';
$strImportFinished = 'Import beendet';
$strIndexes = 'Indizes';
$strIndexHasBeenDropped = 'Index %s wurde entfernt.';
$strIndex = 'Index';
$strIndexName = 'Indexname:';
$strIndexType = 'Indextyp:';
$strIndexWarningMultiple = 'Es sollte nicht mehr als ein Index des Typs %s für die Spalte `%s` gesetzt sein';
$strIndexWarningPrimary = 'Die Index-Typen INDEX und PRIMARY sollten nicht gleichzeitig für die Spalte `%s` gesetzt sein';
$strIndexWarningTable = 'Warnungen bei den Indizes der Tabelle `%s`';
$strIndexWarningUnique = 'Die Index-Typen INDEX und UNIQUE sollten nicht gleichzeitig für die Spalte `%s` gesetzt sein';
$strInnoDBAutoextendIncrement = 'Autoerweiterungs-Schrittgröße';
$strInnoDBAutoextendIncrementDesc = 'Die Größe, um die ein Tablespace erweitert wird, wenn er voll ist.';
$strInnoDBBufferPoolSizeDesc = 'Die Größe des Arbeitsspeicherpuffers, den InnoDB verwendet, um Daten und Indizes zwischenzuspeichern.';
$strInnoDBBufferPoolSize = 'Größe des Speicherpuffers';
$strInnoDBDataFilePath = 'Datendateien';
$strInnoDBDataHomeDirDesc = 'Der Pfad des Verzeichnisses, unter welchem alle InnoDB-Datendateien abgelegt werden.';
$strInnoDBDataHomeDir = 'Pfad für Datendateien';
$strInnoDBPages = 'Seiten';
$strInnodbStat = 'InnoDB-Status';
$strInsecureMySQL = 'Ihre Konfigurationsdatei enthält Einstellungen (Benutzer &quot;root&quot; ohne Passwort), welche denen des MySQL-Standardbenutzers entsprechen. Wird Ihr MySQL-Server mit diesen Einstellungen betrieben, so können Unbefugte leicht von außen auf ihn zugreifen. Sie sollten diese Sicherheitslücke unbedingt schließen!';
$strInsertAsNewRow = ' Als neuen Datensatz speichern ';
$strInsertBookmarkTitle = 'Bitte benennen Sie Ihre gespeicherte Abfrage';
$strInsertedRowId = 'Letzte automatisch eingefügte ID:';
$strInsertedRows = 'Eingefügte Zeilen:';
$strInsert = 'Einfügen';
$strInsertNewRow = 'Neue Zeile einfügen';
$strInsertTextfiles = 'Textdatei in Tabelle einfügen';
$strInstructions = 'Befehle';
$strInternalNotNecessary = '* Eine interne Beziehung ist nicht notwendig, wenn sie bereits im InnoDB-Format vorliegt.';
$strInternalRelations = 'Interne Beziehungen';
$strInUse = 'in Benutzung';

$strJapanese = 'Japanisch';
$strJumpToDB = 'Zur Datenbank &quot;%s&quot; springen.';
$strJustDeleteDescr = 'Die &quot;gelöschten&quot; Benutzer könnten weiterhin wie gewohnt auf den Server zugreifen, bis die Benutzertabellen neu geladen werden.';
$strJustDelete = 'Die Benutzer aus den Benutzertabellen löschen.';

$strKeepPass = 'Kennwort nicht verändert';
$strKeyname = 'Name';
$strKill = 'Beenden';
$strKorean = 'Koreanisch';

$strLandscape = 'Querformat';
$strLatchedPages = 'Belegte Seiten';
$strLatexCaption = 'Tabellenbeschriftung';
$strLatexContent = 'Inhalt der Tabelle __TABLE__';
$strLatexContinuedCaption = 'Fortgesetzte Tabellenbeschriftung';
$strLatexContinued = '(Fortsetzung)';
$strLatexIncludeCaption = 'Tabellenbeschriftung einfügen';
$strLatexLabel = 'Kennzeichen';
$strLaTeX = 'LaTeX';
$strLaTeXOptions = 'LaTeX-Optionen';
$strLatexStructure = 'Struktur der Tabelle __TABLE__';
$strLatvian = 'Lettisch';
$strLengthSet = 'Länge/Set*';
$strLimitNumRows = 'Einträge pro Seite';
$strLineFeed = 'Zeilenvorschub: \\n';
$strLinesTerminatedBy = 'Zeilen getrennt mit';
$strLinkNotFound = 'Der Verweis wurde nicht gefunden.';
$strLinksTo = 'Verweise';
$strLithuanian = 'Litauisch';
$strLoadExplanation = 'Die beste Methode zur Verarbeitung der hochgeladenen Datei durch MySQL ist standardmäßig aktiviert.  Wählen Sie bei Problemen bitte die andere Methode.';
$strLoadMethod = 'LOAD-Methode';
$strLocalhost = 'Lokal';
$strLocationTextfile = 'Datei';
$strLoginInformation = 'Logininformationen';
$strLogin = 'Login';
$strLogout = 'Neu einloggen';
$strLogPassword = 'Kennwort:';
$strLogServer = 'Server';
$strLogUsername = 'Benutzername:';
$strLongOperation = 'Diese Operation könnte einige Zeit beanspruchen. Trotzdem weitermachen?';

$strMaximumSize = 'Maximale Dateigröße: %s%s';
$strMbExtensionMissing = 'Die PHP-Erweiterung "mbstring" wurde nicht gefunden, trotzdem jedoch scheinen Sie einen Mehrbyte-Zeichensatz zu verwenden. Ohne besagte Erweiterung ist phpMyAdmin nicht in der Lage Zeichenketten zu trennen, was zu unerwarteten Ergebnissen führen kann.';
$strMbOverloadWarning = 'Sie haben die Option "mbstring.func_overload" in Ihrer PHP-Konfiguration aktiviert. Diese ist nicht kompatibel zu phpMyAdmin, weshalb es zu Problemen und Datenverlust kommen kann.';
$strMIME_available_mime = 'Verfügbare MIME-Typen';
$strMIME_available_transform = 'Verfügbare Umwandlungen';
$strMIME_description = 'Beschreibung';
$strMIME_MIMEtype = 'MIME-Typ';
$strMIME_nodescription = 'Für diese Umwandlung ist keine Beschreibung verfügar.<br />Für weitere Informationen wenden Sie sich bitte an den Autoren der Funktion &quot;%s&quot;.';
$strMIME_transformation = 'Darstellungsumwandlung';
$strMIME_transformation_note = 'Um eine Liste aller verfügbaren MIME-Typen-Umwandlungen und deren Optionen zu sehen, klicken Sie bitte auf %sUmwandlungen%s';
$strMIME_transformation_options_note = 'Bitte die Werte für die Umwandlungsoptionen in folgendem Format angeben:: \'a\',\'b\',\'c\'...<br />Wann immer Sie ein Backslash ("\") oder ein einfaches Anführungszeichen ("\'") verwenden,<br \>setzen Sie bitte ein Backslash vor das Zeichen.  (z.B.: \'\\\\xyz\' or \'a\\\'b\').';
$strMIME_transformation_options = 'Umwandlungsoptionen';
$strMIMETypesForTable = 'MIME TYPEN DER TABELLE';
$strMIME_without = 'Kursiv dargestellte MIME-Typen besitzen keine untergliederten Umwandlungen.';
$strModifications = 'Änderungen gespeichert.';
$strModifyIndexTopic = 'Index modifizieren';
$strModify = 'Verändern';
$strMoreStatusVars = 'Weitere Statusvariablen';
$strMoveTableOK = 'Tabelle %s wurde nach %s verschoben.';
$strMoveTableSameNames = 'Tabelle kann nicht mit gleichem Namen verschoben werden!';
$strMoveTable = 'Verschiebe Tabelle nach (Datenbank<b>.</b>Tabellenname):';
$strMultilingual = 'multilingual';
$strMustSelectFile = 'Bitte geben Sie eine Datei an, die eingefügt werden soll.';
$strMyISAMDataPointerSizeDesc = 'Standardmäßige Größe des Pointers, welcher von CREATE TABLE für MyISAM-Tabellen verwendet wird, sofern die Option MAX_ROWS nicht angegeben wird.';
$strMyISAMDataPointerSize = 'Größe des Datenpointers';
$strMyISAMMaxExtraSortFileSizeDesc = 'Wenn das Erzeugen der temporären Datei für schnelle Index-Erzeugung um diesen Wert größer sein würde als die Benutzung des Schlüssel-Caches, wird die Schlüssel-Cache-Methode bevorzugt.';
$strMyISAMMaxExtraSortFileSize = 'Maximum Größe temporärer Dateien bei Indexerstellung';
$strMyISAMMaxSortFileSizeDesc = 'Die maximale Größe der temporären Datei, die MySQL benutzen darf, während es den Index erzeugt (während REPAIR, ALTER TABLE oder LOAD DATA INFILE).';
$strMyISAMMaxSortFileSize = 'Maximale Größe temporärer Dateien beim Sortieren';
$strMyISAMRecoverOptions = 'Autoreperatur-Modus'; 
$strMyISAMRecoverOptionsDesc = 'Der Modus der automatischen Wiederherstellung abgestürzter MyISAM-Tabellen, wie über den Startparameter --myisam-recover angegeben.';
$strMyISAMRepairThreadsDesc = 'Wenn dieser Wert größer als 1 ist, werden MyISAM-Tabellenindizes wärend einer Reperatur oder eines Sortierungsprozesses parallel erstellt (jeder Index in einem separaten Thread).';
$strMyISAMRepairThreads = 'Reperaturthreads';
$strMyISAMSortBufferSizeDesc = 'Der Puffer, der beim Sortieren des Indexes zugewiesen wird, wenn man ein REPAIR oder ausführt oder Indizes mit CREATE INDEX oder ALTER TABLE erzeugt.';
$strMyISAMSortBufferSize = 'Größe des Sortierungspuffers'; 
$strMySQLCharset = 'MySQL-Zeichensatz';
$strMySQLConnectionCollation = 'Zeichensatz / Kollation der MySQL-Verbindung';
$strMySQLReloaded = 'Die MySQL-Benutzertabellen wurden neu geladen.';
$strMySQLSaid = 'MySQL meldet: ';
$strMySQLServerProcess = 'Verbunden mit MySQL %pma_s1% auf %pma_s2% als %pma_s3%';
$strMySQLShowProcess = 'Prozesse anzeigen';
$strMySQLShowStatus = 'MySQL-Laufzeit-Informationen anzeigen';
$strMySQLShowVars = 'MySQL-System-Variablen anzeigen';

$strName = 'Name';
$strNeedPrimaryKey = 'Es sollte ein Primärschlüssel für diese Tabelle definiert werden.';
$strNext = 'Nächste';
$strNoActivity = 'Da Sie seit mindestens %s Sekunden inaktiv waren, wurden Sie automatisch abgemeldet. Bitte melden Sie sich erneut an.';
$strNoDatabases = 'Keine Datenbanken';
$strNoDatabasesSelected = 'Es wurden keine Datenbanken ausgewählt.';
$strNoDescription = 'keine Beschreibung';
$strNoDetailsForEngine = 'Für dieses Tabellenformat sind keine Statusinformationen verfügbar';
$strNoDropDatabases = 'Die Anweisung "DROP DATABASE" wurde deaktiviert.';
$strNoExplain = 'SQL-Erklärung umgehen';
$strNoFrames = 'phpMyAdmin arbeitet besser mit einem <b>Frame</b>-fähigen Browser.';
$strNoIndex = 'Kein Index definiert!';
$strNoIndexPartsDefined = 'Keine Indizes definiert.';
$strNoModification = 'Keine Änderung';
$strNo = 'Nein';
$strNone = 'keine';
$strNoOptions = 'Für dieses Format sind keine Optionen vorhanden';
$strNoPassword = 'Kein Kennwort';
$strNoPermission = 'Der Webserver hat keine Schreibrechte um die Datei %s zu speichern.';
$strNoPhp = 'ohne PHP-Code';
$strNoPrivileges = 'Keine Rechte';
$strNoQuery = 'Kein SQL-Befehl!';
$strNoRights = 'Sie haben nicht genug Rechte um fortzufahren!';
$strNoRowsSelected = 'Es wurden keine Datensätze ausgewählt.';
$strNoSpace = 'Zu wenig Speicherplatz um die Datei %s zu speichern.';
$strNoTablesFound = 'Es wurden keine Tabellen in der Datenbank gefunden.';
$strNoThemeSupport = 'Die Unterstützung für Oberflächendesigns ist deaktiviert. Bitte überprüfen Sie Ihre Konfiguration und / oder Ihre Designs im Verzeichnis %s.';
$strNotNumber = 'Das ist keine Zahl!';
$strNotOK = 'fehlerhaft';
$strNotSet = 'Die Tabelle <b>%s</b> wurde entweder nicht gefunden oder in der Kofigurationsdatei %s nicht gesetzt.';
$strNoUsersFound = 'Es wurden keine Benutzer gefunden.';
$strNoValidateSQL = 'SQL-Validierung umgehen';
$strNull = 'Null';
$strNumSearchResultsInTable = '%s Treffer in der Tabelle <i>%s</i>';
$strNumSearchResultsTotal = '<b>Insgesamt</b> <i>%s</i> Treffer';
$strNumTables = 'Tabellen';

$strOftenQuotation = 'Häufig Anführungszeichen. Optional bedeutet, dass nur Textfelder von den angegeben Zeichen eingeschlossen sind.';
$strOK = 'OK';
$strOperations = 'Operationen';
$strOperator = 'Operator';
$strOptimizeTable = 'Optimiere Tabelle';
$strOptionalControls = 'Optional. Bestimmt, wie Sonderzeichen kenntlich gemacht werden.';
$strOptionally = 'optional';
$strOr = 'oder';
$strOverhead = 'Überhang';
$strOverwriteExisting = 'Bestehende Datei(en) überschreiben';

$strPageNumber = 'Seite:';
$strPagesToBeFlushed = 'Zurückzuschreibende Seiten';
$strPaperSize = 'Papiergröße';
$strPartialText = 'gekürzte Textfelder';
$strPasswordChanged = 'Das Kennwort für %s wurde geändert.';
$strPasswordEmpty = 'Es wurde kein Kennwort angegeben!';
$strPasswordHashing = 'Password-Verschlüsselung';
$strPassword = 'Kennwort';
$strPasswordNotSame = 'Die eingegebenen Kennwörter sind nicht identisch!';
$strPdfDbSchema = 'Schema der Datenbank "%s" - Seite %s';
$strPdfInvalidTblName = 'Die Tabelle "%s" existiert nicht!';
$strPdfNoTables = 'keine Tabellen';
$strPerHour = 'pro Stunde';
$strPerMinute = 'pro Minute';
$strPerSecond = 'pro Sekunde';
$strPersian = 'Persisch';
$strPhoneBook = 'Telefonbuch';
$strPHP40203 = 'Sie verwenden die PHP-Version 4.2.3, welche leider fehlerhaft im Umgang mit Multibyte-Zeichenketten (mbstring) ist. Dieser Fehler ist in der PHP-Datenbank als Bug-Report #19404 dokumentiert. Aus diesem Grund wird diese PHP-Version nicht für den Betrieb von phpMyAdmin empfohlen.';
$strPhp = 'PHP-Code erzeugen';
$strPHPVersion = 'PHP-Version';
$strPmaDocumentation = 'phpMyAdmin-Dokumentation';
$strPmaUriError = 'Das <tt>$cfg[\'PmaAbsoluteUri\']</tt>-Verzeichnis MUSS in Ihrer Konfigurationsdatei angegeben werden!';
$strPolish = 'Polnisch';
$strPortrait = 'Hochformat';
$strPos1 = 'Anfang';
$strPrevious = 'Vorherige';
$strPrimaryKeyHasBeenDropped = 'Der Primärschlüssel wurde gelöscht.';
$strPrimaryKeyName = 'Der Name des Primärschlüssels muss PRIMARY lauten!';
$strPrimaryKeyWarning = 'Der Name des Primärschlüssels darf <b>nur</b> "PRIMARY" lauten.';
$strPrimary = 'Primärschlüssel';
$strPrint = 'Drucken';
$strPrintView = 'Druckansicht';
$strPrintViewFull = 'Druckansicht (vollständige Textfelder)';
$strPrivDescAllPrivileges = 'Enthält alle Rechte bis auf GRANT.';
$strPrivDescAlter = 'Erlaubt das Verändern der Struktur bestehender Tabellen.';
$strPrivDescCreateDb = 'Erlaubt das Erstellen neuer Datenbanken und Tabellen.';
$strPrivDescCreateTbl = 'Erlaubt das Erstellen neuer Tabellen.';
$strPrivDescCreateTmpTable = 'Erlaubt das Erstellen temporärer Tabellen.';
$strPrivDescDelete = 'Erlaubt das Löschen von Daten.';
$strPrivDescDropDb = 'Erlaubt das Löschen ganzer Datenbanken und Tabellen.';
$strPrivDescDropTbl = 'Erlaubt das Löschen ganzer Tabellen.';
$strPrivDescExecute = 'Erlaubt das Ausführen gespeicherter Prozeduren; Hat keinen Effekt in dieser MySQL-Version.';
$strPrivDescFile = 'Erlaubt das Importieren von Daten aus und das Exportieren in externe Dateien.';
$strPrivDescGrant = 'Erlaubt das Hinzufügen von Benutzern und Rechten ohne den die Benutzerprofile neu laden zu müssen.';
$strPrivDescIndex = 'Erlaubt das Erstellen und Löschen von Indizes.';
$strPrivDescInsert = 'Erlaubt das Hinzufügen und Ersetzen von Daten.';
$strPrivDescLockTables = 'Erlaubt die Sperrung bestimmter Tabellen.';
$strPrivDescMaxConnections = 'Begrenzt die Anzahl neuer Verbindungen, welche ein Benutzer pro Stunde aufbauen darf.';
$strPrivDescMaxQuestions = 'Begrenzt die Anzahl der Abfragen, welche ein Benutzer pro Stunde senden darf.';
$strPrivDescMaxUpdates = 'Begrenzt die Anzahl der Veränderungen, welche ein Benutzer pro Stunde an allen Datenbanken und Tabellen vornehmen darf.';
$strPrivDescProcess3 = 'Erlaubt das Beenden fremder Prozesse.';
$strPrivDescProcess4 = 'Erlaubt das Anzeigen der vollen Abfragen in der Prozessliste.';
$strPrivDescReferences = 'Hat keinen Effekt in dieser MySQL-Version.';
$strPrivDescReload = 'Erlaubt das erneute Laden von Servereinstellungen und das Leeren der Zwischenspeicher zur Laufzeit.';
$strPrivDescReplClient = 'Erlaubt dem Benutzer zu fragen, wo sich die Master- bzw. Slave-Systeme befinden';
$strPrivDescReplSlave = 'Wird für die Replication-Slave-Systeme benötigt.';
$strPrivDescSelect = 'Erlaubt das Auslesen von Daten.';
$strPrivDescShowDb = 'Gewährt Zugang zur vollständigen Datenbankliste.';
$strPrivDescShutdown = 'Erlaubt das Beenden des Servers.';
$strPrivDescSuper = 'Erlaubt eine Verbindung, selbst wenn die maximale Anzahl an Verbindungen bereits erreicht ist; Wird für viele administrative Operationen, wie das Setzen globaler Variables oder das Beenden fremder Prozesse, vorausgesetzt.';
$strPrivDescUpdate = 'Erlaubt das Verändern von gespeicherten Daten.';
$strPrivDescUsage = 'Keine Rechte.';
$strPrivileges = 'Rechte';
$strPrivilegesReloaded = 'Die Benutzerprofile wurden neu geladen.';
$strProcesslist = 'Prozesse';
$strPutColNames = 'Feldnamen in die erste Zeile setzen';

$strQBE = 'Abfrageeditor';
$strQBEDel = 'Entf.';
$strQBEIns = 'Einf.';
$strQueryFrame = 'Abfragefenster';
$strQueryOnDb = ' SQL-Befehl in der Datenbank <b>%s</b>:';
$strQuerySQLHistory = 'SQL-Verlaufsprotokoll';
$strQueryStatistics = '<b>Abfragestatistik</b>: Seit seinem Start wurden %s Abfragen an diesen MySQL-Server gesandt.';
$strQueryTime = 'die Abfrage dauerte %01.4f sek';
$strQueryType = 'Abfrageart';
$strQueryWindowLock = 'Abfrage vor Änderungen außerhalb des Fensters schützen';

$strReadRequests = 'Leseanfragen';
$strReceived = 'Empfangen';
$strRecords = 'Einträge';
$strReferentialIntegrity = 'Prüfe referentielle Integrität:';
$strRefresh = 'Aktualisieren';
$strRelationalSchema = 'Beziehungsschema';
$strRelationNotWorking = 'Die zusätzlichen Funktionen für verknüpfte Tabellen wurden automatisch deaktiviert. Klicken Sie %shier%s um herauszufinden warum.';
$strRelationsForTable = 'RELATIONEN DER TABELLE';
$strRelations = 'Tabellenverknüpfungen';
$strRelationView = 'Beziehungsübersicht';
$strReloadFailed = 'MySQL Neuladen fehlgeschlagen.';
$strReloadingThePrivileges = 'Lade die Benutzertabellen neu';
$strReloadMySQL = 'Benutzertabellen neu laden';
$strRemoveSelectedUsers = 'Die ausgewählten Benutzer löschen';
$strRenameDatabaseOK = 'Datenbank %s wurde umbenannt zu %s';
$strRenameTableOK = 'Tabelle %s wurde umbenannt in %s.';
$strRenameTable = 'Tabelle umbenennen in';
$strRepairTable = 'Repariere Tabelle';
$strReplace = 'Ersetzen';
$strReplaceNULLBy = 'Ersetze NULL durch';
$strReplaceTable = 'Tabelleninhalt ersetzen';
$strReset = 'Zurücksetzen';
$strResourceLimits = 'Ressourcenbeschränkungen';
$strReType = 'Wiederholen';
$strRevokeAndDelete = 'Den Benutzern alle Rechte entziehen und sie anschließend aus den Benutzertabellen löschen.';
$strRevokeAndDeleteDescr = 'Die Benutzer würden weiterhin das USAGE-Recht behalten, bis die Benutzertabellen neu geladen werden.';
$strRevoke = 'Entfernen';
$strRevokeMessage = 'Sie haben die Rechte für %s entfernt.';
$strRomanian = 'Rumänisch';
$strRowLength = 'Zeilenlänge';
$strRowsFrom = 'Datensätze, beginnend ab';
$strRowSize = 'Zeilengröße';
$strRowsModeFlippedHorizontal = 'horizontal (gedrehte Bezeichner)';
$strRowsModeHorizontal = 'untereinander';
$strRowsModeOptions = '%s angeordnet und wiederhole die Kopfzeilen nach %s Datensätzen.';
$strRowsModeVertical = 'nebeneinander';
$strRowsStatistic = 'Zeilenstatistik';
$strRows = 'Zeilen';
$strRunning = 'auf %s';
$strRunQuery = 'SQL-Befehl ausführen';
$strRunSQLQuery = 'SQL-Befehl(e) in Datenbank %s ausführen';
$strRussian = 'Russisch';

$strSaveOnServer = 'Datei auf dem Server in Verzeichnis %s speichern';
$strSave = 'Speichern';
$strScaleFactorSmall = 'Der Skalierungsfaktor ist zu klein, sodass das Schema nicht auf eine Seite passt!';
$strSearchFormTitle = 'Durchsuche die Datenbank';
$strSearchInTables = 'In der / den Tabelle(n):';
$strSearchNeedle = 'Zu suchende Wörter oder Werte (Platzhalter: "%"):';
$strSearchOption1 = 'mindestens eines der Wörter';
$strSearchOption2 = 'alle Wörter';
$strSearchOption3 = 'genau diese Zeichenkette';
$strSearchOption4 = 'als regulären Ausdruck';
$strSearchResultsFor = 'Suchergebnisse für "<i>%s</i>" %s:';
$strSearch = 'Suche';
$strSearchType = 'Finde:';
$strSecretRequired = 'Ab sofort muss ein geheimes Passwort zur Verschlüsselung in der Konfigurationsdatei gesetzt werden (blowfish_secret).';
$strSelectADb = 'Bitte Datenbank auswählen';
$strSelectAll = 'Alle auswählen';
$strSelectBinaryLog = 'Binäre Protokolldatei zur Anzeige auswählen';
$strSelectFields = 'Felder auswählen (mind. eines):';
$strSelectNumRows = 'in der Abfrage';
$strSelectTables = 'Tabellenauswahl';
$strSend = 'Senden';
$strSent = 'Gesendet';
$strServerChoice = 'Server Auswählen';
$strServerNotResponding = 'Der Server antwortet nicht.';
$strServer = 'Server';
$strServerStatus = 'Laufzeit-Informationen';
$strServerStatusUptime = 'Dieser MySQL-Server läuft bereits %s. Er wurde am %s gestartet.';
$strServerTabProcesslist = 'Prozesse';
$strServerTabVariables = 'Variablen';
$strServerTrafficNotes = '<b>Servertraffic</b>: In diesen Tabellen wird der Netzwerktraffic dieses MySQL-Servers seit dessen Start aufgeführt.';
$strServerVars = 'Servervariablen und -einstellungen';
$strServerVersion = 'Server Version';
$strSessionValue = 'Wert für diese Sitzung';
$strSetEnumVal = 'Wenn das Feld vom Typ \'ENUM\' oder \'SET\' ist, benutzen Sie bitte das Format: \'a\',\'b\',\'c\',....<br />Wann immer Sie ein Backslash ("\") oder ein einfaches Anführungszeichen ("\'") verwenden,<br \>setzen Sie bitte ein Backslash vor das Zeichen.  (z.B.: \'\\\\xyz\' or \'a\\\'b\').';
$strShowAll = 'Alles anzeigen';
$strShowColor = 'mehrfarbig';
$strShowDatadictAs = 'Format des Strukturverzeichnisses';
$strShowFullQueries = 'Zeige die SQL-Abfragen vollständig an';
$strShowGrid = 'Gitterlinien anzeigen';
$strShowingRecords = 'Zeige Datensätze ';
$strShowPHPInfo = 'PHP-Informationen anzeigen';
$strShowTableDimension = 'Tabellendimensionen anzeigen.';
$strShowTables = 'Tabellen anzeigen';
$strShowThisQuery = 'SQL-Befehl hier wieder anzeigen';
$strShow = 'Zeige';
$strSimplifiedChinese = 'Vereinfachtes Chinesisch';
$strSingly = '(einmalig)';
$strSize = 'Größe';
$strSlovak = 'Slovakisch';
$strSlovenian = 'Slovenisch';
$strSocketProblem = '(evtl. ist auch der Socket des lokalen MySQL-Servers socket nicht korrekt konfiguriert)';
$strSortByKey = 'Nach Schlüssel sortieren';
$strSort = 'Sortierung';
$strSpaceUsage = 'Speicherplatzverbrauch';
$strSpanish = 'Spanisch';
$strSplitWordsWithSpace = 'Die Wörter werden durch Leerzeichen (" ") getrennt.';
$strSQLExportCompatibility = 'SQL-Export-Kompatibilität';
$strSQLExportType = 'Exporttyp';
$strSQLOptions = 'SQL-Optionen';
$strSQLParserBugMessage = 'Möglicherweise haben Sie einen Bug im SQL-Parser entdeckt. Bitte überprüfen Sie Ihre Abfrage genaustens, insbesondere auf falsch gesetzte oder nicht geschlossene Anführungszeichen. Eine weitere Ursache könnte darin liegen, dass Sie versuchen eine Datei mit binären Daten, welche nicht von Anführungszeichen eingeschlossen sind, hochzuladen. Sie können alternativ versuchen Ihre Abfrage über das MySQL-Kommandozeileninterface zu senden. Die MySQL-Fehlerausgabe, falls vorhanden, kann Ihnen auch bei der Fehleranalyse helfen. Falls Sie weiterhin Probleme haben sollten oder der Parser dort versagt, wo die Kommandozeile erfolgreich ist, so reduzieren Sie bitte Ihre Abfrage auf den Befehl, welcher die Probleme verursacht, und senden Sie uns einen Bugreport mit den Datenausschnitt, den Sie weiter unten auf dieser Seite finden.:';
$strSQLParserUserError = 'Es scheint einen Fehler in Ihrer MySQL-Abfrage zu geben. Die MySQL-Fehlerausgabe, falls vorhanden, kann Ihnen auch bei der Fehleranalyse helfen.';
$strSQLQuery = 'SQL-Befehl';
$strSQLResult = 'SQL-Abfrageergebnis';
$strSQL = 'SQL';
$strSQPBugInvalidIdentifer = 'Ungültiger Bezeichner';
$strSQPBugUnclosedQuote = 'Nicht geschlossene Anführungszeichen';
$strSQPBugUnknownPunctuation = 'Unbekannte Interpunktion';
$strStatCheckTime = 'Letzter Check am';
$strStatCreateTime = 'Erzeugt am';
$strStatement = 'Angaben';
$strStatUpdateTime = 'Aktualisiert am';
$strStatus = 'Status';
$strStorageEngines = 'Tabellenformate';
$strStorageEngine = 'Tabellenformat';
$strStrucCSV = 'CSV-Daten';
$strStrucData = 'Struktur und Daten';
$strStrucDrop = 'Mit \'DROP TABLE\'';
$strStrucExcelCSV = 'CSV-Daten für MS Excel';
$strStrucNativeExcel = 'Excel-Datei';
$strStrucOnly = 'Nur Struktur';
$strStructPropose = 'Tabellenstruktur analysieren';
$strStructure = 'Struktur';
$strSubmit = 'Abschicken';
$strSuccess = 'Ihr SQL-Befehl wurde erfolgreich ausgeführt.';
$strSum = 'Gesamt';
$strSwedish = 'Schwedisch';
$strSwitchToDatabase = 'Zu kopierter Datenbank wechseln';
$strSwitchToTable = 'Zur kopierten Tabelle wechseln';

$strTableComments = 'Tabellen-Kommentar';
$strTableEmpty = 'Der Tabellenname ist leer!';
$strTableHasBeenDropped = 'Die Tabelle %s wurde gelöscht.';
$strTableHasBeenEmptied = 'Die Tabelle %s wurde geleert.';
$strTableHasBeenFlushed = 'Die Tabelle %s wurde geschlossen und zwischengespeicherte Daten gespeichert.';
$strTableMaintenance = 'Hilfsmittel';
$strTableOfContents = 'Inhalt';
$strTableOptions = 'Tabellenoptionen';
$strTables = '%s Tabellen';
$strTableStructure = 'Tabellenstruktur für Tabelle';
$strTable = 'Tabelle';
$strTableType = 'Tabellentyp';
$strTakeIt = 'auswählen';
$strTblPrivileges = 'Tabellenspezifische Rechte';
$strTextAreaLength = 'Wegen seiner Länge ist dieses<br />Feld vielleicht nicht editierbar.';
$strThai = 'Thai';
$strTheContent = 'Der Inhalt Ihrer Datei wurde eingefügt.';
$strTheContents = 'Der Inhalt der CSV-Datei ersetzt die Einträge mit den gleichen Primär- oder Unique-Schlüsseln.';
$strTheme = 'Oberflächendesign';
$strTheTerminator = 'Der Trenner zwischen den Feldern.';
$strThisHost = 'Dieser Host';
$strThisNotDirectory = 'Dies ist kein Verzeichnis';
$strThreadSuccessfullyKilled = 'Der Prozess %s wurde erfolgreich abgebrochen.';
$strTime = 'Dauer';
$strToggleScratchboard = 'Klemmbrett anzeigen';
$strTotal = 'insgesamt';
$strTotalUC = 'Insgesamt';
$strTraditionalChinese = 'Traditionelles Chinesisch';
$strTraditionalSpanish = 'Traditionelles Spanisch';
$strTraffic = 'Traffic';
$strTransformation_application_octetstream__download = 'Zeigt einen Link an, um die binären Daten eines Feldes downloaden zu können. Die erste Option benennt den Dateinamen. Die zweite Option kann einen Spaltennamen der Tabelle benennen, aus dem der Dateiname geholt werden soll. Sollte die zweite Option gesetzt sein ist es notwendig, die erste Option auf einen Leerstring zu setzen (\'\')';
$strTransformation_image_jpeg__inline = 'Ein klickbares Vorschaubild anzeigen. Optionen: Breite, Höhe in Pixeln (berücksichtigt Seitenverhältnis)';
$strTransformation_image_jpeg__link = 'Einen Link zum Bild anzeigen, z.B. zum Download von BLOB-Daten.';
$strTransformation_image_png__inline = 'Siehe image/jpeg: inline';
$strTransformation_text_plain__dateformat = 'Wandelt ein TIME, TIMESTAMP oder DATETIME-Feld und formatiert es unter Berücksichtigung des lokalen Zeitformats. Erste Option: Differenz (in Stunden) zur Addition/Subtraktion der aktuellen Zeit (Standard: 0). Zweite Option: Zeitformat anstelle des lokalen, Variablen siehe PHPs strftime().';
$strTransformation_text_plain__external = 'Nur für LINUX: Startet ein externes Programm und verwendet die Daten des Feldes für die Standardeingabe. Stellt innerhalb von phpMyAdmin die Standardausgabe des externen Programmes dar. Die Voreinstellung wurde für Tidy optimiert, um HTML code optisch zu formatieren. Aus Sicherheitsgründen müssen Sie die Datei libraries/transformations/text_plain__external.inc.php von Hand bearbeiten um weitere Programme hinzuzufügen. Die erste Option ist die Nummer des dort hinterlegten Programmes und die zweite Option legt die Parameter für das externe Programm fest. Die dritte Option bestimmt, falls auf 1 gesetzt, dass die Ausgabe mit htmlspecialchars() formatiert wird (Standard: 1). Die vierte Option bestimmt, falls auf 1 gesetzt, ob ein NOWRAP-Parameter der Tabellenzelle hinzugefügt wird um einen automatischen Umbruch der Standardausgabe zu verhindern (Standard: 1)';
$strTransformation_text_plain__formatted = 'Behält Ursprungsformatierung des Feldes bei. Kein Escaping oder Umlautwandlung wird durchgeführt.';
$strTransformation_text_plain__imagelink = 'Benutzt den Inhalt eines Feldes um ein Bild und einen Link dazu darzustellen. Die erste Option ist ein Präfix vor dem eigentlichen Feldinhalt wie "http://www.domain.com". Zweite Option ist die Breite des Bildes, die dritte Option die Höhe des Bildes in Pixeln.';
$strTransformation_text_plain__link = 'Benutzt den Inhalt eines Feldes um einen Link darzustellen. Die erste Option ist ein Präfix vor dem eigentlichen Feldinhalt wie "http://www.domain.com". Zweite Option ist der darzustellende Titel des Links';
$strTransformation_text_plain__substr = 'Stellt nur einen Teil des Feldinhaltes dar. Die erste Option definiert die Position des Textes ab dem die Ausgabe startet (Standard: 0), die zweite Option gibt an wieviel Zeichen ab dort dargestellt werden sollen. Falls diese Option leer ist, wird der gesamte verbleibende Text dargestellt. Die dritte Option kann einen Text enthalten, der bei partieller Ausgabe des Textes angehängt wird, um eine Abschneidung kenntlich zu machen (Standard: ...).';
$strTruncateQueries = 'Zeige die SQL-Abfragen verkürzt an';
$strTurkish = 'Türkisch';
$strType = 'Typ';

$strUkrainian = 'Ukrainisch';
$strUncheckAll = 'Auswahl entfernen';
$strUnicode = 'Unicode';
$strUnique = 'Unique';
$strUnknown = 'unbekannt';
$strUnselectAll = 'Auswahl entfernen';
$strUpdatePrivMessage = 'Die Rechte für %s wurden geändert.';
$strUpdateProfileMessage = 'Benutzer wurde geändert.';
$strUpdateQuery = 'Aktualisieren';
$strUpdComTab = 'Bitte lesen Sie in der Dokumentation nach, wie Sie die Struktur Ihrer Spaltenkommentartabelle aktualisieren können';
$strUpgrade = 'Sie sollten auf %s %s oder neuer umsteigen.';
$strUsage = 'Verbrauch';
$strUseBackquotes = ' Tabellen- und Feldnamen in einfachen Anführungszeichen ';
$strUseHostTable = 'Verwende Hosttabelle';
$strUserAlreadyExists = 'Der Benutzer %s existiert bereits!';
$strUser = 'Benutzer';
$strUserEmpty = 'Kein Benutzername eingegeben!';
$strUserName = 'Benutzername';
$strUserNotFound = 'Der gewählte Benutzer wurde in der Benutzertabelle nicht gefunden.';
$strUserOverview = 'Benutzerübersicht';
$strUsersDeleted = 'Die gewählten Benutzer wurden gelöscht.';
$strUsersHavingAccessToDb = 'Benutzer mit Zugriff auf &quot;%s&quot;';
$strUseTabKey = 'Mittels TAB-Taste von Feld zu Feld springen, oder mit STRG+Pfeiltasten beliebig bewegen';
$strUseTables = 'Verwendete Tabellen';
$strUseTextField = 'Textfeld verwenden';
$strUseThisValue = 'Diesen Wert verwenden';

$strValidateSQL = 'SQL validieren';
$strValidatorError = 'Bei der Initialisierung des SQL-Validators ist ein Fehler aufgetreten. Bitte überprüfen Sie, ob Sie die in der %sDokumentation%s beschriebenen php-Erweiterungen installiert haben.';
$strValue = 'Wert';
$strVar = 'Variable';
$strVersionInformation = 'Versionsinformationen';
$strView = 'Ansicht';
$strViewDumpDatabases = 'Dump (Schema) der Datenbanken anzeigen';
$strViewDumpDB = 'Dump (Schema) der Datenbank anzeigen';
$strViewDump = 'Dump (Schema) der Tabelle anzeigen';
$strViewHasBeenDropped = 'Die Ansicht %s wurde gelöscht';

$strWebServerUploadDirectoryError = 'Auf das festgelegte Upload-Verzeichnis kann nicht zugegriffen werden.';
$strWebServerUploadDirectory = 'Upload-Verzeichnis auf dem Webserver';
$strWelcome = 'Willkommen bei %s';
$strWestEuropean = 'Westeuropäisch';
$strWildcard = 'Platzhalter';
$strWindowNotFound = 'Das Ziel-Browserfenster konnte nicht aktualisiert werden. Möglicherweise wurde das Ursprungsfenster geschlossen oder der Browser verhindert den Zugriff aufgrund von Ihren Sicherheitseinstellungen.';
$strWithChecked = 'markierte:';
$strWriteRequests = 'Schreibanfragen';
$strWritingCommentNotPossible = 'Es können keine Kommentare geschrieben werden';
$strWritingRelationNotPossible = 'Es können keine Spaltenbeziehungen gespeichert werden.';
$strWrongUser = 'Falscher Benutzername/Kennwort. Zugriff verweigert.';

$strXML = 'XML';

$strYes = 'Ja';

$strZeroRemovesTheLimit = 'Anmerkung: Der Wert 0 (null) entfernt die Beschränkung.';
$strZip = 'Zip-komprimiert';

// To translate:

$strPrivDescAlterDb = 'Allows altering the structure of existing tables as well as changing the default charset and collation of databases.';  //to translate
$strPrivDescAlterRoutine = 'Allows altering and dropping stored routines.';  //to translate
$strPrivDescCreateRoutine = 'Allows creating stored routines.';  //to translate
$strPrivDescCreateUser = 'Allows creating, dropping and renaming unser accounts.';  //to translate
$strPrivDescCreateView = 'Allows creating new views.';  //to translate
$strPrivDescExecute5 = 'Allows executing stored routines.';  //to translate
$strPrivDescShowView = 'Allows performing SHOW CREATE VIEW queries.';  //to translate

$strRoutines = 'Routines';  //to translate

$strTransformation_application_octetstream__hex = 'Displays hexadecimal representation of data.';  //to translate
$strInvalidFieldCount = 'Table must have at least one field.';  //to translate
$strInvalidRowNumber = '%d is not valid row number.';  //to translate
$strInvalidColumnCount = 'Column count has to be larger than zero.';  //to translate
$strInvalidFieldAddCount = 'You have to add at least one field.';  //to translate
$strAndThen = 'and then';  //to translate
?>
